gchecky.model.result_t

Package gchecky :: Module model :: Class result_t |
[hide private]
[frames] | no frames]

# Class result_t

source code

    object --+
             |
     gxml.Node --+
                 |
                result_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| shipping_name = `String:PATH(@shipping-name):REQ:EMPTY`
| address_id = `String:PATH(@address-id):REQ:EMPTY`
| total_tax = `Node:PATH(total-tax):OPT:{ price_t }`
| shipping_rate = `Node:PATH(shipping-rate):OPT:{ price_t }`
| shippable = `gxml.Boolean('shippable', required= False)`
| merchant_code_results = `Node:PATH(merchant-code-results):OPT:{`...``
| _fields = ``{``'``address_id``'``:` String:PATH(@address-id):REQ:EMPTY`,` `'``...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### merchant_code_results Value:
      Node:PATH(merchant-code-results):OPT:{ merchant_code_results_t }

  ### _fields list of meta-Fields of this class. Value:
      {'address_id': String:PATH(@address-id):REQ:EMPTY,
       'merchant_code_results': Node:PATH(merchant-code-results):OPT:{ merch
      ant_code_results_t },
       'shippable': ??,
       'shipping_name': String:PATH(@shipping-name):REQ:EMPTY,
       'shipping_rate': Node:PATH(shipping-rate):OPT:{ price_t },
       'total_tax': Node:PATH(total-tax):OPT:{ price_t }}